"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _parse = require("css/lib/parse");

var _parse2 = _interopRequireDefault(_parse);

var _cssToReactNative = require("css-to-react-native");

var _cssToReactNative2 = _interopRequireDefault(_cssToReactNative);

var _rem = require("./transforms/rem");

var _camelCase = require("./utils/camelCase");

var _allEqual = require("./utils/allEqual");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var shorthandBorderProps = ["border-radius", "border-width", "border-color", "border-style"];

var transform = function transform(css) {
  var _parseCSS = (0, _parse2.default)(css),
      stylesheet = _parseCSS.stylesheet;

  var result = {};

  for (var r in stylesheet.rules) {
    var rule = stylesheet.rules[r];
    for (var s in rule.selectors) {
      var selector = rule.selectors[s];
      selector = selector.replace(/\.|#/g, "");

      var styles = void 0;

      styles = result[selector] = result[selector] || {};

      for (var d in rule.declarations) {
        var declaration = rule.declarations[d];
        if (declaration.type !== "declaration") continue;

        var property = declaration.property;
        var value = (0, _rem.remToPx)(declaration.value);

        if (shorthandBorderProps.indexOf(property) > -1) {
          (function () {
            // transform single value shorthand border properties back to
            // shorthand form to support styling `Image`.
            var transformed = (0, _cssToReactNative2.default)([[property, value]]);
            var vals = Object.keys(transformed).map(function (key) {
              return transformed[key];
            });
            if ((0, _allEqual.allEqual)(vals)) {
              var replacement = {};
              replacement[(0, _camelCase.camelCase)(property)] = vals[0];
              Object.assign(styles, replacement);
            } else {
              Object.assign(styles, transformed);
            }
          })();
        } else {
          Object.assign(styles, (0, _cssToReactNative2.default)([[property, value]]));
        }
      }
    }
  }
  return result;
};

exports.default = transform;